# Authors

## Project Lead

* Oscar Valenzuela B. - Project creator and maintainer

---

For a complete list of all contributors, please see the [GitHub contributors page](https://github.com/SemClone/osslili/graphs/contributors).